@@ -1,10 +1,19 @@
 
 # get soil depth based on morphology
 estimateSoilDepth <- function(f, name='hzname', top='hzdept', bottom='hzdepb', p='Cr|R|Cd', no.contact.depth=NULL, no.contact.assigned=NULL) {
+  
+  # sanity check: this function will only operate on an SPC
+  if(! class(f) == 'SoilProfileCollection')
+    stop('`f` must be a SoilProfileCollection object')
+  
   # sanity check: this function works on a single soil profile
   if(length(f) > 1)
     stop('This function will only work when applied to a single soil profile, see manual page for details.')
   
+  # sanity check: horizon name, top, bottom must be present in source SPC
+  if(! all(c(name, top, bottom) %in% horizonNames(f)))
+     stop('horizon name, top, or bottom column not correctly specified')
+  
   # extract horizons
   h <- horizons(f)
   
